#ifndef NT2_INCLUDE_FUNCTIONS_EXPM_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_EXPM_HPP_INCLUDED

#include <nt2/linalg/include/functions/expm.hpp>

#endif
